;
; robocop petscii (plus/4 version)
;
; released by arkanix labs in july 2020
;
; www.arkanixlabs.com
;
; code by
; aNdy (CSDb id=6404)
;
; graphics by
; w0rm (CSDb id=32190)
;
; music by
; aNdy (CSDb id=6404)
;
; special thanks to
; luca (CSDb id=3973)
;
; this source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; questions about the source code or binaries
; can be asked on the arkanix labs forum...
; http://www.arkanixlabs.com/forum/index.php


; setup code =================================

; the name and file format for the assembled program

		!to "sourcebuild.prg",cbm

; claw in the binary data...

		* = $5c00
tmusic	!binary "data\tmusic.bin"

		* = $6800
gmusic	!binary "data\gmusic.bin"
		
		* = $2000
		!binary "data\charset.chr"
		
		* = $3000
		!binary "data\roboset.chr"

; some label assignments	
				
scrn_ram			= $2c00
col_ram				= $2800
col_ram_eol			= $2827		
		
; some more label assignments (zp variables)

music_flag			= $e0				; flag so we know what music to play!
greets_flag			= $e1				; flag to indicate whether greets mode is on!
sync				= $e2				; interupt sync variable

; add a BASIC startline (SYS 16384) for auto-run after loading

		* = $1001
		!word code_entry-2
		!byte $00,$00,$9e
		!text "16384"
		!byte $00,$00,$00

; entry point for the code

		* = $4000
				
code_entry

; stop interrupts, disable the roms and set up interrupt pointers	

		sei							; poke the interrupts in the eye temporarily
		
		sta $ff3f
		ldx #$40
		lda #$00
		sta $ff06
		
		lda #int & 255					; some irq stuff
		sta $fffe
		lda #int >> 8
		sta $ffff

		lda #$00						; starting point of raster on screen ($00)
		sta $ff0b

		inc $ff09
		
		lda #$1b
		sta $ff06		

		lda $ff12
		and #$03						; keep lowest 2 bits (sound)	
		ora #$c0						; $08 = $2000, $10 = $4000, etc.
		sta $ff12
		lda #$2f
		sta $ff14
		
		cli								; kickstart the interrupts again

; initialise the game music driver	
			
		jsr gmusic+$00		
						
; set greets mode to off so the colourwash running on interupt is inactive		
		
		lda #$00
		sta greets_flag
		
; and music flag to '0' so no music is played at the start		
		
		sta music_flag

; end setup code =================================


; main runtime code =================================			
		
; setup the screen for the very first run

		jsr clear_screen			; clear screen with subroutine
		
; point to the partial robocop game charset at $3000		
	
		lda #$30
		sta $ff13
		
; print the robocop style 'boot' message

		ldx #$00
		lda #$35					
bootcol_loop						; make the 5 lines we want the boot
		sta col_ram+800,x			; message on all green!
		sta col_ram+840,x
		sta col_ram+880,x
		sta col_ram+920,x
		sta col_ram+960,x			
		inx
		cpx #$0d
		bne bootcol_loop

		ldx #$00
boot_loop1
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+800,x			; boot message!

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+800,x

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda boot_message1,x
		sta scrn_ram+800,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long		

		inx
		cpx #$0b
		bne boot_loop1		
		
		ldx #$00
boot_loop2
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+840,x			; boot message!

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+840,x

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda boot_message2,x
		sta scrn_ram+840,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long		

		inx
		cpx #$09
		bne boot_loop2			
		
		ldx #$00
boot_loop3
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+880,x			; boot message!

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+880,x

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda boot_message3,x
		sta scrn_ram+880,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long		

		inx
		cpx #$0a
		bne boot_loop3			
		
		ldx #$00
boot_loop4
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+920,x			; boot message!

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+920,x

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda boot_message4,x
		sta scrn_ram+920,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long		

		inx
		cpx #$0d
		bne boot_loop4	
				
		ldx #$00
boot_loop5
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+960,x			; boot message!

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+960,x

		ldy #$01					; a little wait
		jsr sync_wait_long
		
		lda boot_message5,x
		sta scrn_ram+960,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long		

		inx
		cpx #$02
		bne boot_loop5

; wait for several seconds so the boot message is readable!
						
		ldy #$99					; approx 3 sec wait...
		jsr sync_wait_long			; ...using a subroutine
		
; clear the boot screen with a subroutine

		jsr clear_screen	
		
; point to the uppercase ROM charset at $2000		
						
		lda #$20
		sta $ff13									
				
; print the intro screen with a loop
	
		ldx #$00					; zero x register
introram_loop						; load up whatver is in the intro
		lda intro_ram,x				; screen table and write to the
		sta scrn_ram,x				; screen in 4 blocks of 250
		lda intro_ram+250,x
		sta scrn_ram+250,x
		lda intro_ram+500,x
		sta scrn_ram+500,x
		lda intro_ram+750,x
		sta scrn_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne introram_loop			; all written? no? loop back!
		
; print the intro screen colour ram
			
		ldx #$00					; zero x register
introcolram_loop					; load up whatver is in the intro
		lda introcolour_ram,x		; colour table and write to the
		sta col_ram,x				; colour ram in 4 blocks of 250
		lda introcolour_ram+250,x
		sta col_ram+250,x
		lda introcolour_ram+500,x
		sta col_ram+500,x
		lda introcolour_ram+750,x
		sta col_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne introcolram_loop		; all written? no? loop back!
		
		lda #$01
		sta music_flag		


; wait for a space press!
		
		jsr space_press				; call space press subroutine
		
; clear the intro screen

		jsr clear_screen			; clear screen with subroutine
		
		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long			; ...using a subroutine							
	
; print the robo petscii screen with a loop, like the intro screen
			
		ldx #$00					; zero x register
roboram_loop						; load up whatver is in the robo
		lda robo_ram,x				; screen table and write to the
		sta scrn_ram,x				; screen in 4 blocks of 250
		lda robo_ram+250,x
		sta scrn_ram+250,x
		lda robo_ram+500,x
		sta scrn_ram+500,x
		lda robo_ram+750,x
		sta scrn_ram+750,x	
		inx
		cpx #$fa					; done 250 writes?
		bne roboram_loop			; all written? no? loop back!
		
		
; print up the petscii screen ram
; using a simple little 'wipe-on'		
	
		ldy #$27
		ldx #$00					; zero x register
robocol_loop						; load up whatver is in the robo
		lda robocol_ram,x			; colour table and write to the
		sta col_ram,x				; colour ram a line at a time
		lda robocol_ram+80,x
		sta col_ram+80,x			; this block does left to right		
		lda robocol_ram+160,x		; reveal of alternating lines
		sta col_ram+160,x	
		lda robocol_ram+240,x
		sta col_ram+240,x			
		lda robocol_ram+320,x
		sta col_ram+320,x				
		lda robocol_ram+400,x
		sta col_ram+400,x			
		lda robocol_ram+480,x
		sta col_ram+480,x			
		lda robocol_ram+560,x
		sta col_ram+560,x			
		lda robocol_ram+640,x
		sta col_ram+640,x			
		lda robocol_ram+720,x
		sta col_ram+720,x			
		lda robocol_ram+800,x
		sta col_ram+800,x
		lda robocol_ram+880,x
		sta col_ram+880,x						
		lda robocol_ram+960,x
		sta col_ram+960,x
		
		lda robocol_ram+40,y		; this block does right to left
		sta col_ram+40,y			; reveal of alternating lines
		lda robocol_ram+120,y
		sta col_ram+120,y
		lda robocol_ram+200,y
		sta col_ram+200,y		
		lda robocol_ram+280,y
		sta col_ram+280,y				
		lda robocol_ram+360,y
		sta col_ram+360,y			
		lda robocol_ram+440,y
		sta col_ram+440,y
		lda robocol_ram+520,y
		sta col_ram+520,y		
		lda robocol_ram+600,y
		sta col_ram+600,y			
		lda robocol_ram+680,y
		sta col_ram+680,y			
		lda robocol_ram+760,y
		sta col_ram+760,y	
		lda robocol_ram+840,y
		sta col_ram+840,y			
		lda robocol_ram+920,y
		sta col_ram+920,y			
									; as well as a counter on the screen print,						
		tya							; we also use 'y' for the small delay,
		pha							; so preserve current 'y' on the stack	
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long
		
		pla							; pull counter value back from the stack
		tay							; and put back into 'y'
		
		inx
		dey
		cpx #$28					; done 40 writes?
		beq robocol_loop_dun		; all written? go down to robocol_loop_dun
		jmp robocol_loop			; no? loop back to robocol_loop!

robocol_loop_dun	
		
; wait for a space press!
		
		jsr space_press
		
; fade out the robo screen

; this works by scanning through the robocop petscii colour ram
; checking for a set colour and if finding that colour,
; changing it to a darker colour to imitate a fade!

; note, this code section could be optimised, but is very easy
; to read 'expanded' like this and since memory isn't an issue
; this will do very nicely ta!

; lame excuses, etc... :D

; start with the blue background...

; blue fade to black = $63 -> $56 -> $36 -> $06 -> $00

		lda #$63					; we check colour ram table for cyan(ish)
		sta check_this
		lda #$56					; and if cyan(ish), change to light blue
		sta change_to

		jsr do_fadeout				; do the check and change now with subroutine!
		jsr fade_delay				; a little delay to make fade visible!
		
		lda #$56					; check for light blue
		sta check_this
		lda #$36					; changing to darker blue 
		sta change_to		
		
		jsr do_fadeout				; do check and change if necessary
		jsr fade_delay				; another delay...

		lda #$36					; darker blue check
		sta check_this
		lda #$06					; to darkest blue!
		sta change_to			
				
		jsr do_fadeout				; etc!
		jsr fade_delay				; etc!
		
		lda #$06					; change darkest blue...
		sta check_this
		lda #$00					; ... to black... DONE!
		sta change_to			
				
		jsr do_fadeout
		jsr fade_delay
		
; now do robo himself...

; grey fade to black = $21 -> $41 -> $51 -> $71 -> reverse to black
; pink fade to black = $12 -> $32 -> $42 -> $52 -> $71 -> reverse to black

		lda #$12					; to fade robo, repeat as for blue
		sta check_this				; above, but we are checking greys!
		lda #$32					; also on this occasion, greys are
		sta change_to				; increased to white first for a flash
									; before fading to black.  nice!
		jsr do_fadeout				; pinks are also done at the same time
		jsr fade_delay				; as the greys so they fade also!
		
		lda #$32
		sta check_this
		lda #$42
		sta change_to		
		
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$21
		sta check_this
		lda #$41
		sta change_to

		jsr do_fadeout				
		
		lda #$42
		sta check_this
		lda #$52
		sta change_to			
		
		jsr do_fadeout
		jsr fade_delay
				
		lda #$41
		sta check_this
		lda #$51
		sta change_to

		jsr do_fadeout				

		lda #$52
		sta check_this
		lda #$51
		sta change_to			
		
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$51
		sta check_this
		lda #$71
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$71
		sta check_this
		lda #$51
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay	
		
		lda #$51
		sta check_this
		lda #$41
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay
		
		lda #$41
		sta check_this
		lda #$21
		sta change_to
					
		jsr do_fadeout
		jsr fade_delay		
		
		lda #$21
		sta check_this
		lda #$00
		sta change_to
					
		jsr do_fadeout

		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long
		
; clear the screen out

		jsr clear_screen			; clear screen with subroutine
		
; point to the partial robocop game charset at $3000		
	
		lda #$30
		sta $ff13
		
; set greets mode to on so the colourwash running on interupt is active	
		
		lda #$01
		sta greets_flag
		
; initialise the title music driver	
			
		jsr tmusic+$00
		
		lda #$02
		sta music_flag			
		
; print the greets screen title

		ldy #$27					; y register set to $27...
		ldx #$00					; ...and zero x register
greets_title_loop					; load up whatver is in the greets
		lda greets_ram_title,x		; screen ram title table and write to the
		sta scrn_ram,x				; screen ram

		lda greets_ram_title+40,y	; reveal right to left
		sta scrn_ram+40,y

		tya							; we also need the 'y' register for the delay
		pha							; so put 'y' into 'a' and store on the stack!
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long
									; the delay routine has finished...	
		pla							; so pull the value stored on the stack into 'a' 
		tay							; and put back into 'y'!  simple!
		
		inx							; increase 'x'
		dey							; decrease 'y'
		cpx #$28					; is 'x' $28?
		bne greets_title_loop		; no?  repeat loop!
									; yes?  then do a small...
		ldy #$19					; ...1/2 sec wait!
		jsr sync_wait_long			; call wait subroutine
		
; print the greets screen title names...
; starting with a cursor on the line after the title
; all a bit lenghty and could be reduced, but nice and
; easy to read again and produces a nice computer
; terminal typewriter effect.  honest!

		lda #$19
		sta scrn_ram+80
		ldy #$03					; a little wait so fake little cursor
		jsr sync_wait_long			; is briefly visible on screen!

		lda #$1a
		sta scrn_ram+80
		ldy #$03					; a little wait so fake large cursor
		jsr sync_wait_long			; is briefy visible on screen!

		lda #$20
		sta scrn_ram+80
	
; now the first block of group greets the line after

; each of the 3 blocks of names is written to the screen
; a letter at a time and consists of 240 characters,
; 6 lines of 40 characters.  i think!  :D
		
		ldx #$00					; zero x register
greets_loop1						; load up whatver is in the robo

		lda #$19
		sta scrn_ram+120,x
		ldy #$02					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+120,x
		ldy #$02					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda greets_ram_names1,x		; screen ram table and write to the
		sta scrn_ram+120,x			; screen ram
		
		ldy #$02					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!		
		
		inx
		cpx #$f0					; done 240 writes?
		bne greets_loop1			; all written? no? loop back!		

; now the next block of group greets			
				
		ldx #$00					; zero x register
greets_loop2						; load up whatver is in the robo

		lda #$19
		sta scrn_ram+360,x
		ldy #$02					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+360,x
		ldy #$02					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda greets_ram_names2,x		; screen ram table and write to the
		sta scrn_ram+360,x			; screen ram
		
		ldy #$02					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!		
		
		inx
		cpx #$f0					; done 240 writes?
		bne greets_loop2			; all written? no? loop back!	
		
; and the final block of group greets			
				
		ldx #$00					; zero x register
greets_loop3						; load up whatver is in the robo

		lda #$19
		sta scrn_ram+600,x
		ldy #$02					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+600,x
		ldy #$02					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda greets_ram_names3,x		; screen ram table and write to the
		sta scrn_ram+600,x			; screen ram
		
		ldy #$02					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!		
		
		inx
		cpx #$f0					; done 240 writes?
		bne greets_loop3			; all written? no? loop back!			
	
; and the final few lines of the greets page...

; fake cursor briefly appears on the first space of the next line

		lda #$19
		sta scrn_ram+840
		ldy #$03					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+840
		ldy #$03					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$20
		sta scrn_ram+840	

; on the next line, print the plus/4 world greeting		
				
		ldx #$00					; zero x register
plus4world_loop						; load up whatver is in the robo

		lda #$19
		sta scrn_ram+880,x
		ldy #$02					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+880,x
		ldy #$02					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda greets_plus4world,x		; screen ram table and write to the
		sta scrn_ram+880,x			; screen ram
		
		ldy #$02					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!		
		
		inx
		cpx #$28					; done 40 writes?
		bne plus4world_loop			; all written? no? loop back!			

; fake cursor briefly appears on the first space of the next line
				
		lda #$19
		sta scrn_ram+920
		ldy #$03					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+920
		ldy #$03					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$20
		sta scrn_ram+920			

; and on the final line, print the arkanix labs web url		
				
		ldx #$00					; zero x register
alwwwad_loop						; load up whatver is in the robo

		lda #$19
		sta scrn_ram+960,x
		ldy #$02					; a little wait so fake little cursor
		jsr sync_wait_long			; is visible on screen!

		lda #$1a
		sta scrn_ram+960,x
		ldy #$02					; a little wait so fake large cursor
		jsr sync_wait_long			; is visible on screen!

		lda arkanix_labs_www,x		; screen ram table and write to the
		sta scrn_ram+960,x			; screen ram
		
		ldy #$02					; a little wait so fake cursor
		jsr sync_wait_long			; is visible on screen!		
		
		inx
		cpx #$28					; done 40 writes?
		bne alwwwad_loop			; all written? no? loop back!		
		
; wait for a space press!
		
		jsr space_press
		
; fade out greets screen

		lda #$1f					; same principle as fading the main
		sta check_this				; robocop petscii screen, so see the
		lda #$2f					; code above for descriptions!
		sta change_to

		jsr do_greetsfade
		jsr fade_delay		
		
		lda #$2f
		sta check_this
		lda #$3f
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay
		
		lda #$3f
		sta check_this
		lda #$4f
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay			
		
		lda #$4f
		sta check_this
		lda #$6f
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay		
	
		lda #$6f
		sta check_this
		lda #$7f
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay
		
		lda #$7f
		sta check_this
		lda #$71
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay					
		
		lda #$71
		sta check_this
		lda #$51
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay			
			
		lda #$51
		sta check_this
		lda #$41
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay			
		
		lda #$41
		sta check_this
		lda #$21
		sta change_to		
		
		jsr do_greetsfade
		jsr fade_delay			

		lda #$21
		sta check_this
		lda #$00
		sta change_to		
				
		jsr do_greetsfade

		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long		

; set greets mode to off so the colourwash running on interupt is inactive	
		
		lda #$00
		sta greets_flag			
				
; clear the screen out

		jsr clear_screen			; clear screen with subroutine
		
; print final 'thank you' message

		ldx #$00
		lda #$35					
coopcol_loop						; make the line we want the thank you
		sta col_ram+480,x			; message on all green!
		inx
		cpx #$28
		bne coopcol_loop
		
		ldx #$00
coop_loop
		lda #$19					; fake cursors again to type out the
		sta scrn_ram+480,x			; thank you message!  see greets above!

		ldy #$03					; a little wait
		jsr sync_wait_long
		
		lda #$1a					; more fake cursorage!
		sta scrn_ram+480,x

		ldy #$01					; a little wait
		jsr sync_wait_long

		lda final_mess,x			; grab the thanks message from this data table!
		sta scrn_ram+480,x
		
		ldy #$01					; a little wait before looping!
		jsr sync_wait_long
				
		inx
		cpx #$28					; done 40 writes?
		bne coop_loop				; all written? no? loop back!
				
		ldy #$33					; approx 1 sec wait...
		jsr sync_wait_long					
		
; space has been pressed so reset some registers

		sei							; stop the interupts

		lda #$00					; reset these registers
		sta $ff06
		sta $ff19
		sta $ff15
		sta $fd58
		sta $ff11

; then reset the plus/4

		sta $ff3e
		jmp $f2a4					; rom call	
		
; end main runtime code =================================					
												

; irq interrupt =========================================

int
		pha  						; preserve some values on the stack
		txa
		pha
		tya
		pha

		inc $ff09
		
		lda greets_flag				; check is greets flag is on...
		cmp #$01					; is it '1'?
		bne music_check				; no?  skip down to music check
									; yes?
		jsr greets_colourwash		; run the colourwash subroutine!
				
music_check
		lda music_flag
		
		cmp #$00
		beq set_sync

		cmp #$01
		beq play_game_tune
		
		jsr tmusic+$03				
		jsr tmusic+$06
		jmp set_sync	

play_game_tune
		
		jsr gmusic+$03
		jsr gmusic+$06

set_sync		
		lda #$01					; set the sync flag to '1'		
		sta sync					; so the main code can run delay timers!			
		
		pla							; pull any preserve values from the
		tay							; stack and put into respective
		pla							; resgisters
		tax
		pla
nmi		rti

; end irq interrupt =============================


; subroutines ===================================


; clear the screen!

clear_screen
		lda #$00					; we'll be wanting a black border
		sta $ff19					; and background then will we?
		sta $ff15					; yup, though so!

		ldx #$00					; zero x register
clsloop
		lda #$20					; code for a blank 'space'
		sta scrn_ram,x				; clear all lines on the screen!
		sta scrn_ram+250,x
		sta scrn_ram+500,x
		sta scrn_ram+750,x
		lda #$00
		sta col_ram,x
		sta col_ram+250,x
		sta col_ram+500,x
		sta col_ram+750,x	
		inx
		cpx #$fa
		bne clsloop
		
		rts		

; space press detect subroutine -----------------------------

space_press
		lda #$7f					; check column 7
		sta $fd30					; write to keyboard matrix
		sta $ff08					; write to keyboard latch
		lda $ff08					; read from keyboard latch
		cmp #$ef					; check keyboard for space press
		bne space_press

		rts
		
; fade screen out subroutine for robo screen -------------------

do_fadeout
		ldx #$00
fade_loop		
		lda robocol_ram,x			; scan the robo colour ram table
		cmp check_this				; check for 'this colour'
		bne line2					; if not that colour, check next line.
		lda change_to				; if colour matches, change the colour
		sta robocol_ram,x			; and store in the colour ram table
		sta col_ram,x				; and the colour ram!
line2		 
		lda robocol_ram+40,x		; each time through the loop, the
		cmp check_this				; colour table is scanned a line at a
		bne line3					; time across the screen a char at a
		lda change_to				; time.  as the colours fade, this
		sta robocol_ram+40,x		; also gives the appearance of fading
		sta col_ram+40,x			; left to right although it happens
line3		 						; so quickly it isn't that noticable.
		lda robocol_ram+80,x
		cmp check_this				; this could be done quicker as 4 blocks
		bne line4					; of 250 read/writes to cover the screen
		lda change_to				; but doing it that way results in a
		sta robocol_ram+80,x		; haphazard colour fade.  this routine 
		sta col_ram+80,x			; in the plus/4 version is an
line4		 						; improvement over the c64 version!
		lda robocol_ram+120,x		; thanks to luca/fire for suggestions!
		cmp check_this
		bne line5
		lda change_to
		sta robocol_ram+120,x
		sta col_ram+120,x			
line5		 
		lda robocol_ram+160,x
		cmp check_this
		bne line6
		lda change_to
		sta robocol_ram+160,x
		sta col_ram+160,x
line6		 
		lda robocol_ram+200,x
		cmp check_this
		bne line7
		lda change_to
		sta robocol_ram+200,x
		sta col_ram+200,x		
line7		 
		lda robocol_ram+240,x
		cmp check_this
		bne line8
		lda change_to
		sta robocol_ram+240,x
		sta col_ram+240,x		
line8		 
		lda robocol_ram+280,x
		cmp check_this
		bne line9
		lda change_to
		sta robocol_ram+280,x
		sta col_ram+280,x
line9
		lda robocol_ram+320,x
		cmp check_this
		bne line10
		lda change_to
		sta robocol_ram+320,x
		sta col_ram+320,x							
line10
		lda robocol_ram+360,x
		cmp check_this
		bne line11
		lda change_to
		sta robocol_ram+360,x
		sta col_ram+360,x		
line11
		lda robocol_ram+400,x
		cmp check_this
		bne line12
		lda change_to
		sta robocol_ram+400,x
		sta col_ram+400,x		
line12
		lda robocol_ram+440,x
		cmp check_this
		bne line13
		lda change_to
		sta robocol_ram+440,x
		sta col_ram+440,x		
line13
		lda robocol_ram+480,x
		cmp check_this
		bne line14
		lda change_to
		sta robocol_ram+480,x
		sta col_ram+480,x	
line14
		lda robocol_ram+520,x
		cmp check_this
		bne line15
		lda change_to
		sta robocol_ram+520,x
		sta col_ram+520,x		
line15
		lda robocol_ram+560,x
		cmp check_this
		bne line16
		lda change_to
		sta robocol_ram+560,x
		sta col_ram+560,x	
line16
		lda robocol_ram+600,x
		cmp check_this
		bne line17
		lda change_to
		sta robocol_ram+600,x
		sta col_ram+600,x		
line17
		lda robocol_ram+640,x
		cmp check_this
		bne line18
		lda change_to
		sta robocol_ram+640,x
		sta col_ram+640,x		
line18
		lda robocol_ram+680,x
		cmp check_this
		bne line19
		lda change_to
		sta robocol_ram+680,x
		sta col_ram+680,x			
line19
		lda robocol_ram+720,x
		cmp check_this
		bne line20
		lda change_to
		sta robocol_ram+720,x
		sta col_ram+720,x		
line20
		lda robocol_ram+760,x
		cmp check_this
		bne line21
		lda change_to
		sta robocol_ram+760,x
		sta col_ram+760,x			
line21
		lda robocol_ram+800,x
		cmp check_this
		bne line22
		lda change_to
		sta robocol_ram+800,x
		sta col_ram+800,x		
line22
		lda robocol_ram+840,x
		cmp check_this
		bne line23
		lda change_to
		sta robocol_ram+840,x
		sta col_ram+840,x
line23
		lda robocol_ram+880,x
		cmp check_this
		bne line24
		lda change_to
		sta robocol_ram+880,x
		sta col_ram+880,x					
line24
		lda robocol_ram+920,x
		cmp check_this
		bne line25
		lda change_to
		sta robocol_ram+920,x
		sta col_ram+920,x			
line25
		lda robocol_ram+960,x
		cmp check_this
		bne chkloop
		lda change_to
		sta robocol_ram+960,x
		sta col_ram+960,x		
chkloop
		inx
		cpx #$28					; each line has 40 checks
		beq fade_loop_dun
		jmp fade_loop
fade_loop_dun		
		rts		
		
		
			
; fade screen out subroutine for greets screen -------------------

do_greetsfade
		ldx #$00
greetsfade_loop
		lda colourwash_table1,x		; same principle as robo fade above!
		cmp check_this
		bne checktable2
		lda change_to
		sta colourwash_table1,x
checktable2
		lda colourwash_table2,x
		cmp check_this
		bne checktablesdun
		lda change_to
		sta colourwash_table2,x	
checktablesdun
		inx
		cpx #$28		
		bne greetsfade_loop
		
		rts		

; delay subroutine for screen fade --------------------		
				
fade_delay				
		ldy #$02					; a little wait before returning
		jsr sync_wait_long
		
		rts
		
; colourwash subroutine for greets screen --------------------

; note: colourwash is run on interupt (called from the irq code)

greets_colourwash
										; colourwash right to left
		lda colourwash_table1+$00		; store the first value in colourwash1 table
		sta colourwash_temp				; into the temp store
		ldx #$00
do_cycle_rl
		lda colourwash_table1+$01,x		; now copy each value in the wash table 1
		sta colourwash_table1+$00,x		; one place to the left
		lda colourwash_table1,x			; and store in the table!
		sta col_ram,x						; then copy to every other line
		sta col_ram+40,x					; on the screen (colour ram)
		sta col_ram+120,x
		sta col_ram+200,x
		sta col_ram+280,x
		sta col_ram+360,x
		sta col_ram+440,x
		sta col_ram+520,x
		sta col_ram+600,x
		sta col_ram+680,x
		sta col_ram+760,x
		sta col_ram+840,x
		sta col_ram+920,x
		inx
		cpx #$28						; repeat above for whole 'line'
		bne do_cycle_rl
		lda colourwash_temp				; then, finally, copy the temp store
		sta colourwash_table1+$28		; to the last value to 'wrap' the colours!	

										; now colourwash left to right!				
		lda colourwash_table2+$28		; same as above, but in reverse to
		sta colourwash_temp				; colour wash the other way!
		ldx #$28
do_cycle_lr
		lda colourwash_table2-$01,x
		sta colourwash_table2+$00,x
		lda colourwash_table2,x
		sta col_ram_eol+40,x
		sta col_ram_eol+120,x
		sta col_ram_eol+200,x
		sta col_ram_eol+280,x
		sta col_ram_eol+360,x
		sta col_ram_eol+440,x
		sta col_ram_eol+520,x
		sta col_ram_eol+600,x
		sta col_ram_eol+680,x
		sta col_ram_eol+760,x
		sta col_ram_eol+840,x
		sta col_ram_eol+920,x											
		dex
		bne do_cycle_lr
		lda colourwash_temp		
		sta colourwash_table2+$00
		
		rts
		
; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait								; wait for sync update in irq code!
		lda #$00						; waits until the sync flag is
		sta sync						; set at the end of the interupt
sw_loop									; code further down.
		cmp sync						; no code in the main loop above
		beq sw_loop						; is executed until the interupt
										; has run it's course!
		rts

; a sync wait delay subroutine ---------------------------------- 		
		
sync_wait_long							; loop around here and above until			
		jsr sync_wait					; 'y' (loaded elsewhere in the code
		dey								; before coming here) is zero
		bne sync_wait_long

		rts				
			   	
; end subroutines ===============================


; data tables here! ==========================

; temp stores for robo screen fade

check_this	!byte $00
change_to	!byte $00

; start-up message data

boot_message1	!byte $43,$4F,$4D,$4D,$41,$4E,$44,$5B,$43,$4F,$4D
boot_message2	!byte $4C,$4F,$41,$44,$20,$42,$49,$4F,$53
boot_message3	!byte $4D,$45,$4D,$4F,$52,$59,$20,$53,$45,$54
boot_message4	!byte $53,$59,$53,$54,$45,$4D,$20,$53,$54,$41,$54,$55,$53
boot_message5	!byte $4F,$4B

; intro screen data

intro_ram
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$01,$0E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$01,$20,$12,$20,$0B,$20,$01,$20,$0E,$20,$09,$20,$18,$20,$20,$20,$0C,$20,$01,$20,$02,$20,$13,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$10,$12,$0F,$04,$15,$03,$14,$09,$0F,$0E,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$6F,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$6F,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$AE,$E8,$E8,$A5,$65,$6F,$6F,$20,$6F,$6F,$6F,$20,$20,$6F,$6F,$20,$E9,$AE,$E8,$E8,$69,$6F,$6F,$20,$6F,$6F,$6F,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$DC,$EC,$FE,$69,$E9,$AE,$E8,$DF,$AE,$E8,$E8,$DF,$E9,$AE,$E8,$DF,$AE,$EC,$E2,$E2,$E9,$AE,$E8,$DF,$AE,$E8,$E8,$DF,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$DC,$FE,$A2,$DF,$DC,$EC,$FB,$E8,$DC,$EC,$E9,$69,$DC,$EC,$FB,$E8,$DC,$5C,$20,$20,$DC,$EC,$FB,$E8,$DC,$EC,$E9,$69,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$AE,$E8,$E8,$A2,$DC,$FC,$FE,$A5,$DC,$E8,$ED,$FC,$DC,$FC,$FE,$A5,$DC,$FC,$68,$62,$E8,$FC,$FE,$A5,$DC,$BE,$77,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$E1,$E8,$EC,$FB,$A5,$5F,$E8,$A5,$69,$E8,$FC,$FE,$EC,$5F,$E8,$A5,$69,$5F,$AE,$E8,$A5,$CD,$E8,$A5,$69,$E8,$61,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$7C,$E2,$7E,$7C,$E2,$20,$77,$77,$20,$77,$77,$77,$20,$20,$77,$77,$20,$20,$78,$E2,$E2,$7E,$77,$77,$20,$77,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$3A,$20,$10,$20,$3A,$20,$05,$20,$3A,$20,$14,$20,$3A,$20,$13,$20,$3A,$20,$03,$20,$3A,$20,$09,$20,$3A,$20,$09,$20,$3A,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$3E,$10,$12,$09,$0D,$05,$20,$10,$05,$12,$13,$0F,$0E,$0E,$05,$0C,$20,$28,$10,$0C,$15,$13,$2F,$34,$20,$05,$04,$09,$14,$09,$0F,$0E,$29,$2E,$2E,$2E,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$31,$3A,$20,$17,$30,$12,$0D,$2E,$2E,$2E,$20,$13,$05,$12,$16,$09,$0E,$07,$20,$15,$10,$20,$14,$08,$05,$20,$07,$12,$01,$10,$08,$09,$03,$13,$20,$20,$20,$20
!byte $20,$20,$32,$3A,$20,$01,$0E,$04,$19,$2E,$2E,$2E,$20,$03,$0F,$0E,$04,$15,$03,$14,$09,$0E,$07,$20,$14,$08,$05,$20,$09,$0E,$13,$14,$12,$15,$0D,$05,$0E,$14,$13,$20
!byte $20,$20,$33,$3A,$20,$01,$0E,$04,$19,$2E,$2E,$2E,$20,$15,$10,$0C,$0F,$01,$04,$09,$0E,$07,$20,$14,$08,$05,$20,$03,$0F,$04,$05,$20,$20,$20,$20,$20,$20,$20,$20,$20
!byte $20,$20,$34,$3A,$20,$0C,$15,$03,$01,$2E,$2E,$2E,$20,$1B,$03,$0C,$01,$13,$13,$09,$06,$09,$05,$04,$20,$10,$0C,$15,$13,$2F,$34,$20,$14,$05,$13,$14,$1D,$20,$20,$20
!byte $20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20

introcolour_ram
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$11,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$61
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$35,$35,$35,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$51,$51,$51,$00,$00,$00,$00,$51,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$35,$00,$35,$00,$35,$00,$35,$00,$35,$00,$35,$00,$35,$00,$35,$00,$00,$00,$35,$00,$35,$00,$35,$00,$35,$00,$35,$35,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$51,$51,$51,$00,$00,$00,$00,$51,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$35,$00,$00,$00,$00,$00,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$11,$35,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$51,$51,$61,$51,$51,$51,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$51,$61,$51,$51,$51,$11,$00,$51,$00,$00,$00,$00,$51,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$61,$41,$41,$41,$41,$11,$61,$51,$00,$61,$51,$51,$00,$00,$61,$51,$00,$51,$41,$41,$41,$41,$61,$51,$00,$61,$51,$51,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$61,$41,$11,$51,$41,$51,$41,$41,$11,$41,$41,$41,$11,$51,$41,$41,$11,$41,$11,$11,$11,$51,$41,$41,$11,$41,$41,$41,$41,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$51,$41,$51,$41,$11,$41,$11,$41,$41,$41,$11,$51,$41,$41,$11,$41,$41,$41,$11,$41,$41,$41,$11,$41,$41,$41,$11,$51,$11,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$51,$41,$41,$41,$41,$41,$11,$51,$11,$41,$41,$41,$11,$41,$11,$51,$11,$41,$11,$41,$51,$41,$11,$51,$11,$41,$11,$11,$11,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$51,$41,$11,$51,$11,$41,$41,$11,$11,$41,$11,$51,$11,$41,$41,$11,$11,$41,$41,$41,$11,$41,$41,$11,$11,$41,$11,$41,$11,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$41,$11,$11,$41,$11,$00,$11,$11,$00,$11,$11,$11,$11,$00,$11,$11,$00,$11,$11,$11,$11,$11,$11,$11,$00,$11,$11,$11,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$35,$35,$35,$00,$6f,$00,$35,$41,$6f,$00,$35,$00,$6f,$51,$35,$00,$6f,$00,$35,$41,$6f,$00,$35,$00,$6f,$11,$35,$00,$6f,$00,$35,$35,$35,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$35,$41,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$35,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$35,$35,$35,$35,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$35
!byte $00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$35,$35,$41,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$35,$00,$35,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$00,$11,$00,$00
!byte $00,$00,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00
!byte $00,$00,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$35,$35,$00,$35,$35,$35,$35,$00,$00,$00,$00,$00,$00,$00,$00,$00
!byte $00,$00,$35,$35,$00,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$35,$00,$35,$35,$35,$35,$35,$00,$00,$00
!byte $61,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$61

; petscii screen data

robo_ram
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$22,$2E,$68,$E6,$66,$68,$20,$56,$5C,$E6,$68,$66,$5C,$E6,$68,$2E,$20,$2E,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$E6,$66,$25,$27,$7E,$68,$25,$66,$DC,$66,$2C,$66,$66,$A3,$66,$DC,$E6,$A3,$66,$56,$5C,$2C,$7F,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$66,$23,$6C,$7E,$1C,$A5,$66,$DC,$E8,$E6,$5C,$22,$66,$66,$E8,$DC,$DC,$E6,$A3,$66,$26,$5C,$2C,$7F,$22,$66,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$E6,$6C,$20,$68,$DC,$DC,$25,$66,$DC,$66,$E6,$20,$23,$DC,$66,$66,$E8,$56,$DC,$E8,$66,$58,$5C,$3A,$21,$21,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$27,$61,$1C,$DC,$DC,$66,$66,$DC,$66,$E8,$66,$5C,$3E,$66,$DC,$E8,$DC,$66,$E8,$DC,$DC,$A3,$5C,$2E,$E1,$20,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$5C,$FF,$68,$DC,$E8,$DC,$25,$DC,$E8,$56,$5C,$E6,$5C,$2E,$68,$66,$66,$E8,$DC,$E6,$E8,$66,$DC,$58,$3B,$68,$5C,$21,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$23,$20,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$76,$8F,$BA,$83,$DC,$90,$56,$DC,$DC,$DC,$E6,$A3,$E6,$20,$68,$DC,$A3,$66,$DC,$56,$DC,$A3,$66,$E6,$20,$E6,$DC,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$27,$E8,$66,$66,$E8,$DC,$E6,$DC,$E8,$56,$66,$26,$66,$21,$5C,$23,$DC,$66,$BE,$E6,$E8,$DC,$E8,$66,$21,$E6,$66,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$21,$FF,$E2,$7F,$7F,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$68,$68,$68,$68,$68,$68,$68,$68,$20,$68,$68,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$1B,$FF,$E2,$7F,$7F,$DC,$66,$9B,$66,$A3,$E8,$E6,$66,$2C,$68,$E6,$E6,$66,$D6,$66,$E6,$E8,$E6,$21,$2C,$E6,$E6,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$76,$E1,$D7,$E1,$E1,$DC,$E8,$25,$63,$63,$63,$63,$63,$20,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$63,$77,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$76,$7C,$C0,$E1,$E1,$62,$62,$68,$64,$64,$64,$64,$64,$20,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$64,$6F,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$3A,$7F,$68,$FF,$FF,$DC,$DC,$58,$E8,$DC,$E6,$D6,$E6,$20,$68,$3E,$E6,$DC,$E6,$DC,$E6,$E8,$E8,$5C,$2C,$E6,$66,$5C,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$5C,$7B,$62,$FF,$FE,$E8,$DC,$E8,$23,$E8,$E8,$E6,$66,$20,$E6,$66,$E8,$D6,$DC,$66,$E8,$66,$E6,$20,$E6,$66,$E6,$5C,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$5C,$56,$C0,$C0,$C0,$AD,$E8,$A5,$E8,$56,$DC,$E8,$5C,$21,$68,$56,$66,$E8,$E6,$E8,$DC,$E6,$2C,$21,$66,$E6,$E6,$7E,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$5C,$1B,$E6,$66,$5C,$E6,$DC,$DC,$E8,$DC,$E6,$BB,$AE,$E6,$E8,$DC,$E8,$E4,$E4,$E7,$E4,$E4,$E8,$E6,$BA,$23,$FF,$2E,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$20,$5C,$5C,$20,$66,$7F,$7C,$DC,$E8,$DC,$E8,$E6,$AD,$9B,$A8,$FE,$EF,$E4,$EC,$F9,$E4,$FC,$A9,$E8,$66,$5C,$25,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$66,$E6,$5C,$20,$25,$20,$20,$20,$7F,$20,$FB,$DC,$E8,$E8,$DC,$AE,$A0,$FC,$FB,$AE,$E8,$E8,$EC,$FE,$BB,$DE,$A5,$61,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $66,$E6,$66,$E6,$66,$E6,$66,$5C,$21,$22,$20,$20,$20,$20,$7F,$20,$FB,$DC,$E8,$DC,$BA,$DC,$E8,$FC,$F8,$F8,$F8,$FE,$A5,$E8,$E8,$E8,$7B,$66,$E6,$66,$E6,$66,$E6,$66
!byte $E6,$66,$E6,$66,$E6,$22,$27,$20,$20,$3A,$23,$20,$20,$20,$20,$20,$6F,$63,$77,$78,$78,$77,$63,$2E,$68,$66,$A3,$66,$E6,$68,$20,$DC,$5C,$E6,$66,$E6,$66,$E6,$66,$E6
!byte $22,$27,$64,$2E,$68,$46,$40,$20,$20,$5C,$22,$5C,$20,$20,$20,$20,$20,$45,$44,$43,$43,$44,$45,$77,$77,$63,$63,$63,$77,$FB,$A3,$E8,$7E,$21,$22,$66,$E6,$66,$E6,$66
!byte $45,$63,$2E,$67,$27,$20,$2E,$20,$20,$20,$3A,$7C,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$2C,$E6,$66,$7E,$40,$46,$52,$22,$64,$27,$22
!byte $68,$66,$2E,$5C,$65,$20,$2E,$20,$20,$2E,$20,$20,$22,$4D,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$20,$64,$64,$2C,$63,$FE,$E6,$22,$20,$2E,$20,$20,$20,$20,$20,$63
!byte $5C,$22,$66,$2E,$7F,$20,$20,$2E,$20,$20,$2E,$20,$20,$20,$45,$44,$43,$52,$2E,$20,$20,$20,$20,$64,$2E,$2C,$52,$46,$E2,$22,$20,$20,$2E,$20,$20,$20,$17,$30,$12,$0D
		
robocol_ram
!byte $63,$63,$63,$56,$56,$56,$36,$36,$06,$06,$06,$06,$21,$41,$41,$41,$21,$21,$21,$21,$41,$51,$21,$41,$21,$21,$21,$21,$21,$06,$06,$06,$36,$36,$36,$56,$56,$56,$63,$63
!byte $63,$63,$56,$56,$56,$36,$36,$06,$06,$06,$06,$21,$21,$41,$71,$51,$41,$21,$21,$41,$41,$41,$51,$71,$51,$41,$21,$21,$21,$21,$06,$06,$06,$36,$36,$36,$56,$56,$56,$63
!byte $63,$56,$56,$56,$36,$36,$06,$06,$06,$21,$21,$21,$41,$71,$51,$41,$41,$21,$21,$21,$41,$41,$51,$51,$71,$51,$41,$21,$21,$21,$21,$06,$06,$06,$36,$36,$36,$56,$56,$56
!byte $56,$56,$56,$56,$36,$36,$06,$06,$21,$21,$21,$41,$51,$71,$51,$41,$41,$21,$21,$21,$21,$41,$51,$51,$71,$51,$41,$41,$21,$21,$21,$21,$06,$06,$06,$36,$36,$56,$56,$63
!byte $63,$56,$56,$36,$36,$06,$06,$06,$21,$21,$41,$51,$71,$51,$41,$41,$21,$21,$21,$21,$21,$41,$41,$51,$71,$51,$51,$41,$41,$21,$21,$21,$00,$06,$06,$36,$36,$36,$56,$56
!byte $56,$56,$56,$36,$36,$06,$06,$21,$21,$21,$41,$51,$71,$51,$41,$21,$21,$21,$21,$21,$21,$41,$41,$51,$51,$71,$51,$41,$41,$21,$21,$21,$21,$06,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$41,$51,$71,$51,$41,$21,$21,$21,$21,$00,$21,$41,$41,$51,$71,$71,$71,$51,$41,$21,$00,$21,$21,$00,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$41,$51,$71,$51,$21,$21,$21,$21,$21,$21,$21,$21,$41,$51,$51,$71,$51,$41,$41,$21,$00,$21,$41,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$41,$51,$71,$51,$21,$21,$21,$21,$21,$21,$21,$41,$41,$51,$51,$71,$51,$41,$41,$21,$21,$21,$41,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$21,$41,$51,$71,$51,$51,$41,$21,$21,$21,$21,$41,$41,$51,$51,$71,$51,$51,$41,$21,$00,$21,$41,$51,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$41,$71,$41,$21,$41,$51,$71,$51,$41,$41,$21,$21,$21,$21,$21,$41,$51,$51,$71,$51,$51,$41,$21,$21,$21,$41,$51,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$41,$21,$51,$51,$21,$41,$51,$71,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$41,$51,$71,$21,$41,$51,$71,$21,$21,$21,$21,$21,$71,$21,$21,$21,$21,$21,$21,$41,$21,$21,$21,$21,$21,$21,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$21,$41,$51,$51,$21,$41,$51,$71,$51,$41,$41,$21,$21,$00,$21,$21,$21,$21,$21,$41,$51,$41,$21,$21,$21,$21,$41,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$06,$21,$21,$21,$21,$41,$41,$51,$71,$51,$41,$21,$21,$00,$21,$21,$21,$21,$41,$51,$41,$21,$21,$21,$21,$41,$41,$21,$06,$06,$36,$36,$56,$56
!byte $56,$56,$36,$36,$06,$06,$06,$21,$21,$21,$41,$41,$41,$41,$51,$71,$51,$41,$21,$21,$21,$21,$21,$21,$51,$41,$21,$21,$21,$21,$41,$41,$21,$21,$06,$06,$36,$36,$56,$56
!byte $63,$56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$41,$21,$12,$32,$42,$52,$52,$52,$52,$42,$52,$52,$52,$52,$42,$42,$52,$52,$52,$42,$32,$12,$06,$06,$06,$36,$36,$56,$56
!byte $56,$56,$56,$36,$36,$06,$06,$21,$21,$21,$41,$21,$21,$12,$12,$32,$42,$42,$52,$52,$52,$52,$32,$32,$32,$32,$32,$32,$32,$52,$42,$32,$21,$06,$06,$36,$36,$36,$56,$56
!byte $63,$56,$56,$36,$36,$06,$06,$06,$21,$21,$41,$21,$00,$21,$00,$12,$32,$32,$42,$52,$52,$52,$52,$32,$32,$32,$32,$32,$52,$42,$42,$32,$21,$06,$06,$36,$36,$36,$56,$63
!byte $63,$63,$56,$56,$36,$36,$06,$06,$21,$21,$21,$21,$21,$00,$21,$00,$12,$12,$32,$42,$32,$42,$52,$52,$42,$42,$42,$52,$42,$42,$32,$12,$21,$06,$36,$36,$36,$56,$56,$56
!byte $63,$63,$63,$56,$36,$36,$06,$21,$21,$21,$21,$21,$21,$21,$00,$00,$21,$12,$12,$12,$12,$12,$12,$21,$21,$41,$41,$41,$21,$21,$00,$21,$21,$06,$36,$36,$36,$56,$56,$63
!byte $63,$63,$21,$21,$21,$21,$21,$56,$21,$21,$21,$21,$21,$21,$21,$21,$00,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$21,$41,$21,$21,$06,$36,$36,$56,$56,$63,$63
!byte $21,$21,$21,$21,$21,$63,$21,$21,$06,$21,$21,$21,$21,$00,$21,$00,$21,$00,$00,$00,$00,$00,$00,$00,$00,$00,$21,$00,$00,$21,$41,$21,$21,$21,$21,$21,$56,$21,$63,$63
!byte $21,$21,$21,$21,$21,$56,$21,$06,$21,$21,$06,$06,$21,$21,$21,$21,$00,$00,$00,$00,$00,$00,$00,$21,$00,$21,$21,$21,$21,$21,$21,$21,$00,$21,$21,$00,$00,$21,$21,$21
!byte $21,$21,$21,$21,$21,$21,$36,$21,$06,$06,$21,$06,$06,$06,$21,$21,$21,$21,$21,$00,$00,$00,$21,$21,$21,$21,$21,$21,$21,$21,$00,$21,$21,$00,$00,$21,$21,$21,$21,$21

; greets screen data

greets_ram_title
!byte $01,$02,$03,$04,$05,$06,$01,$02,$07,$08,$09,$0B,$0C,$20,$0D,$20,$01,$02,$0F,$10,$11,$12,$20,$13,$14,$03,$04,$15,$16,$15,$16,$17,$18,$09,$07,$08,$13,$14,$11,$12
!byte $21,$22,$23,$24,$25,$26,$21,$22,$27,$28,$29,$2B,$2C,$20,$2D,$2E,$21,$22,$2F,$30,$31,$32,$20,$33,$34,$23,$24,$35,$36,$35,$36,$20,$38,$29,$27,$28,$33,$34,$31,$32

greets_ram_names1
!byte $5B,$41,$42,$53,$45,$4E,$43,$45,$5B,$5B,$5B,$5B,$41,$42,$59,$53,$53,$20,$43,$4F,$4E,$4E,$45,$43,$54,$49,$4F,$4E,$5B,$5B,$5B,$41,$52,$54,$53,$54,$41,$54,$45,$5B
!byte $41,$54,$45,$20,$42,$49,$54,$5B,$5B,$41,$54,$4C,$41,$4E,$54,$49,$53,$5B,$5B,$42,$4F,$4F,$5A,$45,$20,$44,$45,$53,$49,$47,$4E,$5B,$5B,$43,$41,$4D,$45,$4C,$4F,$54
!byte $43,$45,$4E,$53,$4F,$52,$20,$44,$45,$53,$49,$47,$4E,$5B,$5B,$43,$48,$4F,$52,$55,$53,$5B,$5B,$43,$48,$52,$4F,$4D,$45,$5B,$5B,$43,$4E,$43,$44,$5B,$5B,$43,$50,$55
!byte $5B,$43,$4F,$53,$49,$4E,$45,$5B,$5B,$43,$52,$45,$53,$43,$45,$4E,$54,$5B,$5B,$43,$52,$45,$53,$54,$5B,$5B,$43,$4F,$56,$45,$52,$54,$20,$42,$49,$54,$4F,$50,$53,$5B
!byte $5B,$44,$45,$46,$45,$4E,$43,$45,$20,$46,$4F,$52,$43,$45,$5B,$5B,$5B,$44,$45,$4B,$41,$44,$45,$4E,$43,$45,$5B,$5B,$44,$45,$53,$49,$52,$45,$5B,$5B,$44,$41,$43,$5B
!byte $5B,$44,$4D,$41,$47,$49,$43,$5B,$5B,$45,$58,$43,$4C,$55,$53,$49,$56,$45,$20,$4F,$4E,$5B,$5B,$5B,$46,$41,$49,$52,$4C,$49,$47,$48,$54,$5B,$5B,$46,$5D,$43,$47,$5B

greets_ram_names2
!byte $46,$49,$52,$45,$5B,$5B,$46,$4C,$41,$54,$5C,$5B,$5B,$46,$4F,$43,$55,$53,$5B,$5B,$46,$52,$45,$4E,$43,$48,$5B,$54,$4F,$55,$43,$48,$5B,$5B,$48,$49,$54,$4D,$45,$4E
!byte $48,$4F,$41,$58,$45,$52,$53,$5B,$5B,$5B,$48,$4F,$4B,$55,$54,$4F,$20,$46,$4F,$52,$43,$45,$5B,$5B,$5B,$5B,$4C,$45,$47,$49,$4F,$4E,$20,$4F,$46,$20,$44,$4F,$4F,$4D
!byte $5B,$4D,$41,$4E,$49,$41,$43,$53,$20,$4F,$46,$20,$4E,$4F,$49,$53,$45,$5B,$5B,$5B,$5B,$4D,$41,$59,$44,$41,$59,$5B,$5B,$5B,$5B,$4D,$45,$41,$4E,$54,$45,$41,$4D,$5B
!byte $5B,$5B,$4D,$45,$54,$41,$4C,$56,$4F,$54,$45,$5B,$5B,$4E,$4F,$4E,$41,$4D,$45,$5B,$5B,$4E,$4F,$53,$54,$41,$4C,$47,$49,$41,$5B,$5B,$4E,$55,$41,$4E,$43,$45,$5B,$5B
!byte $5B,$4F,$46,$46,$45,$4E,$43,$45,$5B,$5B,$4F,$4E,$53,$4C,$41,$55,$47,$48,$54,$5B,$5B,$4F,$52,$42,$5B,$5B,$4F,$58,$59,$52,$4F,$4E,$5B,$5B,$50,$41,$44,$55,$41,$5B
!byte $5B,$5B,$5B,$50,$45,$52,$46,$4F,$52,$4D,$45,$52,$53,$5B,$5B,$50,$4C,$55,$53,$48,$5B,$5B,$50,$50,$43,$53,$5B,$5B,$50,$53,$59,$54,$52,$4F,$4E,$49,$4B,$5B,$5B,$5B

greets_ram_names3
!byte $52,$45,$50,$54,$49,$4C,$49,$41,$5B,$5B,$52,$45,$53,$4F,$55,$52,$43,$45,$5B,$5B,$52,$47,$43,$44,$5B,$5B,$53,$45,$43,$55,$52,$45,$5B,$5B,$53,$48,$41,$50,$45,$20
!byte $5B,$5B,$53,$49,$44,$45,$20,$42,$5B,$5B,$5B,$53,$49,$4E,$47,$55,$4C,$41,$52,$5B,$5B,$53,$4C,$41,$53,$48,$5B,$5B,$53,$4C,$49,$50,$53,$54,$52,$45,$41,$4D,$5B,$5B
!byte $5B,$53,$55,$43,$43,$45,$53,$53,$20,$41,$4E,$44,$20,$54,$52,$43,$5B,$5B,$53,$54,$59,$4C,$45,$5B,$5B,$53,$55,$49,$43,$59,$4F,$20,$49,$4E,$44,$55,$53,$54,$5B,$5B
!byte $5B,$5B,$5B,$5B,$54,$41,$52,$51,$55,$41,$52,$54,$5B,$5B,$5B,$54,$45,$4D,$50,$45,$53,$54,$5B,$5B,$5B,$54,$45,$4B,$5B,$5B,$5B,$54,$52,$49,$41,$44,$5B,$5B,$5B,$5B
!byte $54,$52,$49,$53,$54,$41,$52,$20,$41,$4E,$44,$20,$52,$45,$44,$20,$53,$45,$43,$54,$4F,$52,$5B,$5B,$5B,$56,$49,$52,$55,$5A,$5B,$5B,$5B,$56,$49,$53,$49,$4F,$4E,$5B
!byte $5B,$57,$4F,$57,$5B,$5B,$5B,$57,$52,$41,$49,$54,$48,$20,$44,$45,$53,$49,$47,$4E,$53,$5B,$5B,$5B,$58,$45,$4E,$4F,$4E,$5B,$5B,$5B,$58,$45,$4E,$54,$41,$58,$5B,$5B

greets_plus4world
!byte $20,$20,$20,$5B,$5B,$5B,$41,$4E,$44,$20,$41,$4C,$4C,$20,$54,$48,$4F,$53,$45,$20,$4F,$4E,$20,$50,$4C,$55,$53,$5F,$5D,$20,$57,$4F,$52,$4C,$44,$5E,$5E,$20,$20,$20

arkanix_labs_www
!byte $20,$57,$20,$57,$20,$57,$20,$5B,$20,$41,$20,$52,$20,$4B,$20,$41,$20,$4E,$20,$49,$20,$58,$20,$4C,$20,$41,$20,$42,$20,$53,$20,$5B,$20,$43,$20,$4F,$20,$4D,$20,$20

; final message data

final_mess
!byte $20,$20,$20,$20,$54,$48,$41,$4E,$4B,$20,$59,$4F,$55,$20,$46,$4F,$52,$20,$59,$4F,$55,$52,$20,$43,$4F,$4F,$50,$45,$52,$41,$54,$49,$4F,$4E,$5B,$20,$20,$20,$20,$20

; colour wash tables

colourwash_table1
		!byte $1f,$2f,$3f,$2f,$3f
		!byte $3f,$3f,$4f,$4f,$4f
		!byte $6f,$4f,$6f,$6f,$6f
		!byte $71,$6f,$71,$7f,$71
		!byte $71,$7f,$71,$6f,$71
		!byte $6f,$6f,$6f,$4f,$6f
		!byte $4f,$4f,$4f,$3f,$3f
		!byte $3f,$2f,$3f,$2f,$1f	
		
colourwash_table2
		!byte $1f,$2f,$3f,$2f,$3f
		!byte $3f,$3f,$4f,$4f,$4f
		!byte $6f,$4f,$6f,$6f,$6f
		!byte $71,$6f,$71,$7f,$71
		!byte $71,$7f,$71,$6f,$71
		!byte $6f,$6f,$6f,$4f,$6f
		!byte $4f,$4f,$4f,$3f,$3f
		!byte $3f,$2f,$3f,$2f,$1f		

; temp store for colour wash effect		
			
colourwash_temp
		!byte $00	